@@ -7,9 +7,16 @@ from faker.providers.lorem.cs_CZ import Provider as CsCzLoremProvider
 
 class TestLoremProvider:
     """Test lorem provider methods"""
+
     custom_word_list = [
-        'danish', 'cheesecake', 'sugar', 'lollipop',
-        'wafer', 'gummies', 'jelly', 'pie',
+        "danish",
+        "cheesecake",
+        "sugar",
+        "lollipop",
+        "wafer",
+        "gummies",
+        "jelly",
+        "pie",
     ]
 
     def test_word_with_defaults(self, faker, num_samples):
@@ -59,26 +66,26 @@ class TestLoremProvider:
 
     def test_sentence_no_words(self, faker, num_samples):
         for _ in range(num_samples):
-            assert faker.sentence(0) == ''
+            assert faker.sentence(0) == ""
 
     def test_sentence_with_inexact_word_count(self, faker, num_samples):
         num_words = 10
         for _ in range(num_samples):
             sentence = faker.sentence(nb_words=num_words)
-            words = sentence.lower().replace('.', '').split()
+            words = sentence.lower().replace(".", "").split()
             assert int(num_words * 0.6) <= len(words) <= int(num_words * 1.4)
 
     def test_sentence_with_exact_word_count(self, faker, num_samples):
         num_words = 10
         for _ in range(num_samples):
             sentence = faker.sentence(nb_words=num_words, variable_nb_words=False)
-            words = sentence.lower().replace('.', '').split()
+            words = sentence.lower().replace(".", "").split()
             assert len(words) == num_words
 
     def test_sentence_with_custom_word_list(self, faker, num_samples):
         for _ in range(num_samples):
             sentence = faker.sentence(ext_word_list=self.custom_word_list)
-            words = sentence.lower().replace('.', '').split()
+            words = sentence.lower().replace(".", "").split()
             assert all(isinstance(word, str) and word in self.custom_word_list for word in words)
 
     def test_sentences(self, faker, num_samples):
@@ -87,7 +94,7 @@ class TestLoremProvider:
             sentences = faker.sentences(nb=num_sentences, ext_word_list=self.custom_word_list)
             assert len(sentences) == num_sentences
             for sentence in sentences:
-                words = sentence.lower().replace('.', '').split()
+                words = sentence.lower().replace(".", "").split()
                 assert all(isinstance(word, str) and word in self.custom_word_list for word in words)
 
     def test_sentence_single_word(self, faker):
@@ -96,26 +103,26 @@ class TestLoremProvider:
 
     def test_paragraph_no_sentences(self, faker, num_samples):
         for _ in range(num_samples):
-            assert faker.paragraph(0) == ''
+            assert faker.paragraph(0) == ""
 
     def test_paragraph_with_inexact_sentence_count(self, faker, num_samples):
         num_sentences = 10
         for _ in range(num_samples):
             paragraph = faker.paragraph(nb_sentences=num_sentences)
-            sentences = paragraph.split('. ')
+            sentences = paragraph.split(". ")
             assert int(num_sentences * 0.6) <= len(sentences) <= int(num_sentences * 1.4)
 
     def test_paragraph_with_exact_sentence_count(self, faker, num_samples):
         num_sentences = 10
         for _ in range(num_samples):
             paragraph = faker.paragraph(nb_sentences=num_sentences, variable_nb_sentences=False)
-            sentences = paragraph.split('. ')
+            sentences = paragraph.split(". ")
             assert len(sentences) == num_sentences
 
     def test_paragraph_with_custom_word_list(self, faker, num_samples):
         for _ in range(num_samples):
             paragraph = faker.paragraph(ext_word_list=self.custom_word_list)
-            words = paragraph.lower().replace('.', '').split()
+            words = paragraph.lower().replace(".", "").split()
             assert all(isinstance(word, str) and word in self.custom_word_list for word in words)
 
     def test_paragraphs(self, faker, num_samples):
@@ -124,7 +131,7 @@ class TestLoremProvider:
             paragraphs = faker.paragraphs(nb=num_paragraphs, ext_word_list=self.custom_word_list)
             assert len(paragraphs) == num_paragraphs
             for paragraph in paragraphs:
-                words = paragraph.lower().replace('.', '').split()
+                words = paragraph.lower().replace(".", "").split()
                 assert all(isinstance(word, str) and word in self.custom_word_list for word in words)
 
     def test_text_with_less_than_four_characters(self, faker, num_samples):
@@ -132,12 +139,16 @@ class TestLoremProvider:
             with pytest.raises(ValueError):
                 faker.text(max_nb_chars=4)
 
-    @pytest.mark.parametrize('num_chars', [10, 50, 150, 10000], ids=[
-        'max_nb_chars < 25',
-        '25 <= max_nb_chars < 100',
-        'max_nb_chars >= 100',
-        'max_nb_chars >> 100',
-    ])
+    @pytest.mark.parametrize(
+        "num_chars",
+        [10, 50, 150, 10000],
+        ids=[
+            "max_nb_chars < 25",
+            "25 <= max_nb_chars < 100",
+            "max_nb_chars >= 100",
+            "max_nb_chars >> 100",
+        ],
+    )
     def test_text_with_valid_character_count(self, faker, num_samples, num_chars):
         for _ in range(num_samples):
             text = faker.text(max_nb_chars=num_chars)
@@ -146,7 +157,7 @@ class TestLoremProvider:
     def test_text_with_custom_word_list(self, faker, num_samples):
         for _ in range(num_samples):
             text = faker.text(ext_word_list=self.custom_word_list)
-            words = re.sub(r'[.\n]+', ' ', text.lower()).split()
+            words = re.sub(r"[.\n]+", " ", text.lower()).split()
             assert all(word in self.custom_word_list for word in words)
 
     def test_texts(self, faker, num_samples):
@@ -154,18 +165,20 @@ class TestLoremProvider:
         num_chars = 25
         for _ in range(num_samples):
             texts = faker.texts(
-                max_nb_chars=num_chars, nb_texts=num_texts,
+                max_nb_chars=num_chars,
+                nb_texts=num_texts,
                 ext_word_list=self.custom_word_list,
             )
             assert len(texts) == num_texts
             for text in texts:
                 assert len(text) <= num_chars
-                words = re.sub(r'[.\n]+', ' ', text.lower()).split()
+                words = re.sub(r"[.\n]+", " ", text.lower()).split()
                 assert all(word in self.custom_word_list for word in words)
 
 
 class TestCsCz:
     """Test cs_CZ lorem provider"""
+
     word_list = [word.lower() for word in CsCzLoremProvider.word_list]
 
     def test_paragraph(self, faker, num_samples):
@@ -173,7 +186,7 @@ class TestCsCz:
         for _ in range(num_samples):
             paragraph = faker.paragraph(nb_sentences=num_sentences)
             assert isinstance(paragraph, str)
-            words = paragraph.replace('.', '').split()
+            words = paragraph.replace(".", "").split()
             assert all(word.lower() in self.word_list for word in words)
 
     def test_paragraphs(self, faker, num_samples):
@@ -182,7 +195,7 @@ class TestCsCz:
             paragraphs = faker.paragraphs(nb=num_paragraphs)
             for paragraph in paragraphs:
                 assert isinstance(paragraph, str)
-                words = paragraph.replace('.', '').split()
+                words = paragraph.replace(".", "").split()
                 assert all(word.lower() in self.word_list for word in words)
 
     def test_sentence(self, faker, num_samples):
@@ -190,7 +203,7 @@ class TestCsCz:
         for _ in range(num_samples):
             sentence = faker.sentence(nb_words=num_words)
             assert isinstance(sentence, str)
-            words = sentence.replace('.', '').split()
+            words = sentence.replace(".", "").split()
             assert all(word.lower() in self.word_list for word in words)
 
     def test_sentences(self, faker, num_samples):
@@ -199,7 +212,7 @@ class TestCsCz:
             sentences = faker.sentences(nb=num_sentences)
             for sentence in sentences:
                 assert isinstance(sentence, str)
-                words = sentence.replace('.', '').split()
+                words = sentence.replace(".", "").split()
                 assert all(word.lower() in self.word_list for word in words)
 
     def test_text(self, faker, num_samples):
@@ -207,7 +220,7 @@ class TestCsCz:
         for _ in range(num_samples):
             text = faker.text(max_nb_chars=num_chars)
             assert isinstance(text, str)
-            words = re.sub(r'[.\n]+', ' ', text).split()
+            words = re.sub(r"[.\n]+", " ", text).split()
             assert all(word.lower() in self.word_list for word in words)
 
     def test_texts(self, faker, num_samples):
@@ -217,7 +230,7 @@ class TestCsCz:
             texts = faker.texts(max_nb_chars=num_chars, nb_texts=num_texts)
             for text in texts:
                 assert isinstance(text, str)
-                words = re.sub(r'[.\n]+', ' ', text).split()
+                words = re.sub(r"[.\n]+", " ", text).split()
                 assert all(word.lower() in self.word_list for word in words)
 
     def test_word(self, faker, num_samples):
